#
# spec file for package ivtv
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           ivtv
BuildRequires:  gcc-c++
Url:            http://ivtvdriver.org/index.php/Main_Page
ExclusiveArch:  %ix86 ppc ppc64 x86_64
Version:        1.4.0
Release:        23.6
Summary:        Driver Implementation for iCompression or Conexant Video Capture Cards
License:        GPL-2.0
Group:          Productivity/Multimedia/Other
Source0:        %{name}-utils-%{version}.tar.bz2
Source1:        preamble
Patch0:         ivtv-optflags.patch
Patch1:         ivtv-splice.patch
Patch2:         ivtv-buffer.patch
Requires:       v4l-utils
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The primary goal of the IVTV project is to provide a "clean room" Linux
open source driver implementation for video capture cards based on the
iCompression iTVC15 or Conexant CX23415/CX23416 MPEG Codec. Examples of
such cards are the Hauppauge PVR 250/350 series of MPEG video capture
cards, the Hauppauge "freestyle", and the AVerMedia M179 AVerTV. The
freestyle has not been tested, but it should work or at least be easy
to get working.

%prep
%setup -q -n ivtv-utils-%{version}
%patch0
%patch1
%patch2

%build
# This package failed when testing with -Wl,-as-needed being default.
# So we disable it here, if you want to retest, just delete this comment and the line below.
export SUSE_ASNEEDED=0
# build utils
make -C utils

%install
# install utils
mkdir -p "%{buildroot}/usr/bin"
make -C utils DESTDIR=$RPM_BUILD_ROOT PREFIX=/usr install
# install suspend file
mkdir -p "%{buildroot}/usr/lib/pm/config.d"
echo "SUSPEND_MODULES=\"ivtv\"" > %{buildroot}/usr/lib/pm/config.d/ivtv.config
# Remove ivtv-ctl and v4l2-ctl which are now provided by v4l-utils package (avoid conflicts during installation)
rm -f %{buildroot}/usr/bin/ivtv-ctl
rm -f %{buildroot}/usr/bin/v4l2-ctl

#
rm -fv doc/install.txt.orig
# not packaged ATM
rm -f %{buildroot}/usr/include/linux/ivtv.h
rm -f %{buildroot}/usr/include/linux/ivtvfb.h

%files
%defattr(-,root,root)
%doc COPYING README ChangeLog doc utils/ivtvfwextract.pl
/usr/bin/*
%dir /usr/lib/pm
%dir /usr/lib/pm/config.d
/usr/lib/pm/config.d/ivtv.config

%changelog
* Tue Apr  8 2014 asterios.dramis@gmail.com
- Removed ivtv-ctl and v4l2-ctl utilities which are now provided by v4l-utils
  package (avoid conflicts during installation) and added a dependency to
  v4l-utils package for them.
* Wed Feb  6 2013 ro@suse.de
- drop off ivtv-firmware to separate package (bnc#757539)
- package pm-config file for ivtv (bnc#781377)
* Wed Sep 12 2012 cfarrell@suse.com
- license update: GPL-2.0
  SPDX format
* Mon May 17 2010 ro@suse.de
- added modalias supplements for firmware package (bnc#534216)
* Mon May 17 2010 ro@suse.de
- update to 1.4.0
  - Updated for kernel 2.6.29.
  - Fix and enhance ivtv private packet decoding.
  - Update to latest v4l2-ctl.
  - Removed v4l2-dbg: use the version from the official v4l-dvb
    repository instead.
* Fri Dec  4 2009 seife@opensuse.org
- de-fuzz the Makefile patch
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Fri Jun 19 2009 coolo@novell.com
- disable as-needed for this package as it fails to build with it
* Fri Feb 27 2009 ro@suse.de
- update to svn to fix build
* Fri Jan  9 2009 olh@suse.de
- use ExclusiveArch as in /SRC/arch/
* Mon Sep 29 2008 ro@suse.de
- update to 1.3.0 (upstream name is now ivtv-utils)
  * ivtvctl has been renamed to ivtv-ctl. This makes it consistent
  with the naming of other v4l2 utilities.
- kmp packages (drivers) are now gone, all in upstream kernel
* Wed Oct 17 2007 ro@suse.de
- update to 1.0.3, the main driver is now upstream and built
  in the kernel source
- here are the ivtvfb and saa717x drivers
* Sun Jun 10 2007 ro@suse.de
- avoid comparison with string literal
* Tue Jun  5 2007 ro@suse.de
- update to 0.10.3
- make it compile with current kernel
* Thu Apr  5 2007 ro@suse.de
- make it compile with current kernel
* Tue Apr  3 2007 ro@suse.de
- added licence files to firmware
* Wed Mar 28 2007 ro@suse.de
- update to 0.10.1
  - Fix bug where the 'App not reading fast enough' message was repeated
    continuously. It should only show it once, until the application is
    reading again.
  - Allow hex input for setting controls (-c option) in v4l2-ctl.
  - Show the actual amount of bytes read from /dev/videoX in the
    LOG_STATUS text.
  - Due to a bad copy-and-paste the i2c subsystem used I2C_HW_B_BT848
    instead of I2C_HW_B_CX2341X.
  - Still allow 256 KB encoder firmwares for compatibility with
    blackbird cards.
  - Fix PIO support.
  - Pass correct values for ENC_MISC(3, ...)
  - Fix ivtvfbctl option handling on ppc.
* Sun Mar 18 2007 ro@suse.de
- removed /lib/firmware directory from filelist (in filesystem)
* Wed Jan 17 2007 ro@suse.de
- hack to build on 2.6.20pre
* Sat Jan 13 2007 ro@suse.de
- update to 0.9.1
- 0.9.1 stable release
  - Fix busy wait loop
  - Remove 2.6.18 workaround: no longer needed in 2.6.19.
- 0.9.0 stable release
  - minor updates for 2.6.19: fix compile warnings and update VIDIOC_G_SLICED_VBI_CAP
  ioctl to the changed v4l2_sliced_vbi_cap struct.
  - Improve the output of VIDIOC_LOG_STATUS.
  - Fix handling of corrupt tveeprom.
- 0.8.2 stable release
  - Fix handling of corrupt tveeprom.
  - Fix busy wait loop
- 0.8.1 stable release
  - vbi test tool accepts -d1 as a shortcut for /dev/video1
  - added videodev2.h in utils since distros often are sloppy
  in updating this file in a new kernel release.
  - some usability improvements to v4l2-ctl. Please note! Some
  options have new names.
  - workaround VIDIOC_INT_S_REGISTER kernel bug (wrong ioctl value
  in the v4l2-common.h header, this is fixed in 2.6.19).
  - saa717x fixes for Japanese cards.
  - reported pix format was V4L2_PIX_FMT_UYVY instead of V4L2_PIX_FMT_HM12.
  - added missing VIDIOC_ENUM_FMT ioctl.
  - added new IVTV_IOC_STOP ioctl (thanks to Martin Dauskardt <md001@gmx.de>)
  - added new IVTV_IOC_PAUSE_BLACK ioctl (thanks to Martin Dauskardt <md001@gmx.de>)
  Similar to IVTV_IOC_PAUSE, but it turns the output black when paused.
  - Fix encoder pause/resume: these two were swapped.
  - Firmware loading has been made more robust
  Thanks to Robert Hardy <rhardy@webcon.ca>.
  - Firmware loading once again supports ppc.
  - Fix nasty bug when loading the init mpeg file
  Thanks to Robert Hardy <rhardy@webcon.ca>.
  - Enabling of newi2c support now depends on the presence of an IR-blaster.
  - No longer turn the digitizer off and on when changing channels, this
  caused the tinny audio!
  - Fix VIDIOC_STREAMOFF support.
  - Detection of Hauppauge cards is now fully based on the tveeprom,
  PCI IDs are ignored. Other cards still use the PCI ID for detection.
  - The detection of the first or second unit of a PVR500 is now done based
  on the PCI 'slot' used on the PVR500 card. The first unit has slot 8,
  the second has slot 9.
  - Added IR-blaster detection, with thanks to Hauppauge's Steven Toth for
  providing this information.
  - Fix initial PAL/SECAM/NTSC tuner defaults.
  - Fix driver cleanup in case an error occurs.
  - Fix VIDIOC_INT_S_AUDIO_ROUTING ioctl.
  - Ripped out dynamic buffer allocation: it never worked right and gave
  some people a lot of grief.
  - Make i2c errors (missing i2c devices) more readable.
* Tue Nov 14 2006 ro@suse.de
- move firmware to /lib/firmware
* Tue Nov 14 2006 ro@suse.de
- update to 0.8.0 (for 2.6.18 kernel release)
  - Many API changes as part of the work to merge the driver
    into the kernel
  - Detect and workaround DMA offsets that can be introduced
    by a DMA error.
  - Sliced VBI always uses PIO, never DMA.
  - Removed test/fwapi, utils/ivtv-detect.
  - Added utils/v4l2-ctl.
* Sat Sep 23 2006 aj@suse.de
- Fix build with glibc 2.5.
* Mon Aug 21 2006 ro@suse.de
- update to current svn to fix build with 2.6.18
* Sun Apr  2 2006 ro@suse.de
- change MODULE_PARM to module_param
* Fri Mar  3 2006 ro@suse.de
- update to current CVS (0.7.0) to run on current kernel (#153549)
* Fri Feb  3 2006 agruen@suse.de
- ivtv.spec: Replace %%arch with %%_target_cpu.
* Fri Feb  3 2006 ro@suse.de
- skip "um" not "uml"
* Tue Jan 31 2006 ro@suse.de
- build kernel-modules locally (KMP)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 ro@suse.de
- update to current 0.4.2 (hopefully build with current kernel)
* Mon Nov 28 2005 ro@suse.de
- added utils/ivtvfwextract.pl to doc files list (#135611)
* Fri Nov  4 2005 ro@suse.de
- try to fix km build by moving videodev2.h to driver subdirectory
* Wed Oct 26 2005 ro@suse.de
- update to 0.4.0
* Sun Aug 14 2005 ro@suse.de
- fix problem in kernel modules Makefile
* Sat Aug 13 2005 ro@suse.de
- update to 0.3.7c
* Fri Aug 12 2005 ro@suse.de
- update to 0.3.3k
* Tue Feb 15 2005 agruen@suse.de
- Don't install the user-space header in the kernel rpm.
* Mon Feb 14 2005 agruen@suse.de
- Fix km_ package makefile.
* Tue Feb  1 2005 ro@suse.de
- update to 0.3.2c
* Thu Jan 20 2005 ro@suse.de
- drop the request_module parts from mod_rename patch
* Wed Jan 19 2005 ro@suse.de
- keep only Makefile2.6 as Makefile in km_ivtv
* Thu Jan 13 2005 ro@suse.de
- rename modules msp3400, tuner, tveeprom to ivtv-xxx
  to avoid clash
* Thu Jan 13 2005 ro@suse.de
- created package (based on work by kraxel)
